==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fon
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Mi zé wémà dokpo gɔna', # MODIF
	'bouton_ajouter_image' => 'Mi zé yɛwli ɖo wémaji gɔna', # MODIF

	// E
	'entree_dimensions' => 'jlɛjlɛ',
	'entree_titre_document' => 'wěmá xótá ',
	'entree_titre_image' => 'titá xótá',

	// I
	'image_tourner_180' => 'lìlɛlílɛ 180°',
	'image_tourner_droite' => 'lìlɛlílɛ 90° yì àɖùsímɛ ',
	'image_tourner_gauche' => 'lìlɛlílɛ 90° yì  àmyɔmɛ',
	'info_document' => 'wémà',
	'info_documents' => 'Wêmà lɛ',
	'info_inclusion_directe' => 'Wémà ɔ gblé:',
	'info_inclusion_vignette' => 'Wémà ɔ gblé:',
	'info_installer_tous_documents' => 'mi sɔ wémà lɛ bí',
	'info_logo_max_taille' => 'Ntùn lɛ dó ná gbló gègé à  @maxi@ (xótòɖáyí é lɔ blo @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_telecharger' => 'ɖɔn sín mɔxwítíxwítí ɔ mɛ :',

	// T
	'texte_documents_joints' => 'Zé gɔ ná wěmámɛYé mɔ àyì ɖé ɖó wékwín é lɔ wú áYé sɔ mɔ ɖê ná nɔ kpɔn wékwín sín winwlán gànjí ɔ ɖó sùpípùmɛ.Amɔ có nú mi ná sɔ wěmà mi tɔn ɖé xlɛ hún mi ván núkún ɖémɛ ɖésú hwɛ', # MODIF
	'texte_documents_joints_2' => 'mi sɔ ɖidé ɖó wěmà lɛ mɛ.', # MODIF
	'titre_documents_joints' => 'wěmà yé gɔná',
	'tout_dossier_upload' => 'Wemágbàví ɖébú ɖê  @ná gbɔ é@',

	// U
	'upload_fichier_zip' => 'Fichier ZIPù',
	'upload_fichier_zip_texte' => 'xótá mi jó ná zé xótá zipù wɛ.',
	'upload_fichier_zip_texte2' => 'xótá é lɔ síwú :',
	'upload_limit' => 'gbètá ɔ kló ɖín @max@.',
	'upload_zip_decompacter' => 'sɔ ɖémɛ ɖê ɖé gbɔn ɔ :',
	'upload_zip_telquel' => 'sɔ ɖémɛ ɖê ɖé gbɔn ɔ  Zip ;'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_fon.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fon
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Mi zé wémà dokpo gɔna', # MODIF
	'bouton_ajouter_image' => 'Mi zé yɛwli ɖo wémaji gɔna', # MODIF

	// E
	'entree_dimensions' => 'jlɛjlɛ',
	'entree_titre_document' => 'wěmá xótá ',
	'entree_titre_image' => 'titá xótá',

	// I
	'image_tourner_180' => 'lìlɛlílɛ 180°',
	'image_tourner_droite' => 'lìlɛlílɛ 90° yì àɖùsímɛ ',
	'image_tourner_gauche' => 'lìlɛlílɛ 90° yì  àmyɔmɛ',
	'info_document' => 'wémà',
	'info_documents' => 'Wêmà lɛ',
	'info_inclusion_directe' => 'Wémà ɔ gblé:',
	'info_inclusion_vignette' => 'Wémà ɔ gblé:',
	'info_installer_tous_documents' => 'mi sɔ wémà lɛ bí',
	'info_logo_max_taille' => 'Ntùn lɛ dó ná gbló gègé à  @maxi@ (xótòɖáyí é lɔ blo @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_telecharger' => 'ɖɔn sín mɔxwítíxwítí ɔ mɛ :',

	// T
	'texte_documents_joints' => 'Zé gɔ ná wěmámɛYé mɔ àyì ɖé ɖó wékwín é lɔ wú áYé sɔ mɔ ɖê ná nɔ kpɔn wékwín sín winwlán gànjí ɔ ɖó sùpípùmɛ.Amɔ có nú mi ná sɔ wěmà mi tɔn ɖé xlɛ hún mi ván núkún ɖémɛ ɖésú hwɛ', # MODIF
	'texte_documents_joints_2' => 'mi sɔ ɖidé ɖó wěmà lɛ mɛ.', # MODIF
	'titre_documents_joints' => 'wěmà yé gɔná',
	'tout_dossier_upload' => 'Wemágbàví ɖébú ɖê  @ná gbɔ é@',

	// U
	'upload_fichier_zip' => 'Fichier ZIPù',
	'upload_fichier_zip_texte' => 'xótá mi jó ná zé xótá zipù wɛ.',
	'upload_fichier_zip_texte2' => 'xótá é lɔ síwú :',
	'upload_limit' => 'gbètá ɔ kló ɖín @max@.',
	'upload_zip_decompacter' => 'sɔ ɖémɛ ɖê ɖé gbɔn ɔ :',
	'upload_zip_telquel' => 'sɔ ɖémɛ ɖê ɖé gbɔn ɔ  Zip ;',
];
